package picturelab;

/**
 * @author Barbara Ericson - Original Collage and Picture code.
 * @author LaSpina - CollageMaker functions refactored into this class with additional code added.
 */
public class CollageMaker {
/**
 * A pair of images is used to create a 4 by 4 collage. If the two images are A and B, then
 * the image created is AB
 *                      BA
 */
   public static Picture create2By2Collage(Picture p1, Picture p2) {
      int w1 = p1.getWidth();
      int h1 = p1.getHeight();
      int w2 = p2.getWidth();
      int h2 = p2.getHeight();
      Picture canvas = new Picture(w1+w2, h1+h2);
      canvas.setTitle(p1.getTitle() + "-" + p2.getTitle());
      canvas.copy(p1, 0, 0);
      canvas.copy(p2, 0, w1); //row, column
      canvas.copy(p2, h1, 0);
      canvas.copy(p1, h1, w1);
      return canvas;
   }
   
   /**
    * The given picture is tinted in various ways to create 9 different images
    * and these are assembled into a three by three pattern,
    * @param p The starting image
    * @return A new image with dimensions 3 X width and height of the original.
    */
   public static Picture create3By3TintedCollage(Picture p) {
      int w = p.getWidth();
      int h = p.getHeight();
      Picture canvas = new Picture(w*3, h*3);
      Picture p2 = new Picture(p);
      p2.zeroBlue();
      Picture p3 = new Picture(p);
      p3.zeroRed();
      //only green:
      Picture p4 = new Picture(p3);
      p4.zeroBlue();
      
      canvas.copy(p,0,0);
      canvas.copy(p2, 0, w);
      canvas.copy(p3, 0, w*2);
      canvas.copy(p3,h,0);
      canvas.copy(p4, h, w);
      canvas.copy(p2, h,w*2);
      canvas.copy(p,h*2,0);
      canvas.copy(p2, h*2,w);
      canvas.copy(p3, h*2,w*2);
      canvas.setTitle(p.getTitle() + "-Tinted");
      
      return canvas;
   }
   
   public static Picture create2By2Mirror(Picture image) {
      Picture mirrorImage = new Picture(image);
      //mirrorImage.verticalReflection();
      mirrorImage.horizontalReflection();
      System.out.print("Dimensions mirrorImage :");
      System.out.println("w=" + mirrorImage.getWidth() +", h="+mirrorImage.getHeight());
      System.out.print("Dimensions image :");
      System.out.println("w=" + image.getWidth() +", h="+ image.getHeight());
      
      return create2By2Collage(image, mirrorImage);
   }
   
   /**
    * The idea of this method is to give students the chance to be creative and see what functions they can create
    * using the tools that have been developed.
    * @param image1
    * @param image2
    * @return A new image that will wither be tinted reflections or just various tints.
    */
   public static Picture createRandomCollage(Picture image1, Picture image2) {
      int w = image1.getWidth();
      int h = image1.getHeight();
      if(image2.getWidth()!= w || image2.getHeight() != h)
         image2 = PictureUtils.scaleTo(image2, w, h);
      
      Picture canvas = new Picture(w*3, h*3);
      Picture p = new Picture(image1);
      if(Math.random() < 0.5)
         p.zeroGreen();
      Picture p2 = new Picture(image1);
      if(Math.random() <0.5)
         p2.zeroBlue();
      else
         p2.zeroGreen();
      Picture p3 = new Picture(image2);
      p3.zeroRed();
      //only green:
      Picture p4 = new Picture(p3);
      p4.zeroBlue();
      double r = Math.random();
      if(r<0.33)
         p3.mirrorTemple();
      else if(r<0.66)
         p3.mirrorVertical();
      else
         p3.horizontalReflection();
         
      
      canvas.copy(p,0,0);
      canvas.copy(p2, 0, w);
      canvas.copy(p3, 0, w*2);
      canvas.copy(p3,h,0);
      //randomly choose one of the originals to place in the center
      if(Math.random()>0.5)
         canvas.copy(image1, h, w);
      else
         canvas.copy(image2,h,w);
      canvas.copy(p2, h,w*2);
      canvas.copy(p,h*2,0);
      canvas.copy(p2, h*2,w);
      canvas.copy(p3, h*2,w*2);
      canvas.setTitle(p.getTitle() + "-Random");
      
      return canvas;
   }
   
   
   /**
    * Method to create a collage of several pictures
    */
   public static Picture createDemoCollage() {
      Picture flower1 = new Picture("flower1.jpg");
      Picture flower2 = new Picture("flower2.jpg");
      Picture canvas = new Picture("640x480.jpg");
      canvas.copy(flower1, 0, 0);
      canvas.copy(flower2, 100, 0);
      canvas.copy(flower1, 200, 0);
      Picture flowerNoBlue = new Picture(flower2);
      flowerNoBlue.zeroBlue();
      canvas.copy(flowerNoBlue, 300, 0);
      canvas.copy(flower1, 400, 0);
      canvas.copy(flower2, 500, 0);
      canvas.mirrorVertical();
      return canvas;
   }

   public static void main(String[] args) {
      Picture p = new Picture("1chocopologie.jpg").scale(0.1, 0.1);
      p.explore();
      
      Picture collage = create3By3TintedCollage(p);
      collage.explore();
   }
}
